import { ElementRef, OnDestroy, EventEmitter, NgZone } from '@angular/core';
import { ControlValueAccessor } from '@angular/forms';
import { ScriptService } from './script.service';
export declare class UeditorComponent implements OnDestroy, ControlValueAccessor {
    private el;
    private zone;
    private ss;
    private instance;
    private value;
    private events;
    loading: boolean;
    path: string;
    config: any;
    loadingTip: string;
    host: ElementRef;
    onReady: EventEmitter<{}>;
    onDestroy: EventEmitter<{}>;
    onContentChange: EventEmitter<{}>;
    constructor(el: ElementRef, zone: NgZone, ss: ScriptService);
    ngOnInit(): void;
    private init(options?);
    private updateValue(value);
    private destroy();
    /**
     * 获取UE实例
     *
     * @readonly
     */
    readonly Instance: any;
    /**
     * 设置编辑器语言
     *
     * @param {('zh-cn' | 'en')} lang
     */
    setLanguage(lang: 'zh-cn' | 'en'): void;
    /**
     * 添加编辑器事件
     *
     * @param {('destroy' | 'reset' | 'focus' | 'langReady' | 'beforeExecCommand' | 'afterExecCommand' | 'firstBeforeExecCommand' | 'beforeGetContent' | 'afterGetContent' | 'getAllHtml' | 'beforeSetContent' | 'afterSetContent' | 'selectionchange' | 'beforeSelectionChange' | 'afterSelectionChange')} eventName
     * @param {Function} fn
     */
    addListener(eventName: 'destroy' | 'reset' | 'focus' | 'langReady' | 'beforeExecCommand' | 'afterExecCommand' | 'firstBeforeExecCommand' | 'beforeGetContent' | 'afterGetContent' | 'getAllHtml' | 'beforeSetContent' | 'afterSetContent' | 'selectionchange' | 'beforeSelectionChange' | 'afterSelectionChange', fn: Function): void;
    /**
     * 移除编辑器事件
     *
     * @param {('destroy' | 'reset' | 'focus' | 'langReady' | 'beforeExecCommand' | 'afterExecCommand' | 'firstBeforeExecCommand' | 'beforeGetContent' | 'afterGetContent' | 'getAllHtml' | 'beforeSetContent' | 'afterSetContent' | 'selectionchange' | 'beforeSelectionChange' | 'afterSelectionChange')} eventName
     */
    removeListener(eventName: 'destroy' | 'reset' | 'focus' | 'langReady' | 'beforeExecCommand' | 'afterExecCommand' | 'firstBeforeExecCommand' | 'beforeGetContent' | 'afterGetContent' | 'getAllHtml' | 'beforeSetContent' | 'afterSetContent' | 'selectionchange' | 'beforeSelectionChange' | 'afterSelectionChange'): void;
    ngOnDestroy(): void;
    writeValue(value: string): void;
    protected onChange: any;
    protected onTouched: any;
    registerOnChange(fn: (_: any) => {}): void;
    registerOnTouched(fn: () => {}): void;
    setDisabledState(isDisabled: boolean): void;
}
